@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  *          Havoc Pennington <hp@redhat.com>
@@ -27,6 +27,8 @@
  *          Tom Tromey <tromey@redhat.com>
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <locale.h>
 #include <errno.h>
@@ -318,7 +320,7 @@ transient_get_xterm_toplevel (void)
   while (xterm != None && !transient_is_toplevel (xterm))
   {
     Window root, parent, *children;
-    int nchildren;
+    unsigned nchildren;
     XQueryTree (dpy, xterm,
                 &root, &parent,
                 &children, &nchildren);
